import { OnInit, AfterViewInit, AfterContentChecked, OnChanges, ElementRef, SimpleChanges, EventEmitter, OnDestroy } from '@angular/core';
import { AgTableHeaderComponent } from '../ag-table-header/ag-table-header.component';
import { AgTableBodyComponent } from '../ag-table-body/ag-table-body.component';
import { AgTableChangeAction } from '../enums/ag-table-change-action.enum';
import { AgTableEvent } from '../events/ag-table-event.event';
import { AgTablePrepareService } from '../services/ag-table-prepare.service';
import { AgTableVirtualScrollService } from '../services/ag-table-virtual-scroll.service';
import { AgTableDataRenderEvent } from '../events/ag-table-data-render.event';
import { Helper } from '../services/helper';
export declare class AgTableComponent implements OnInit, OnChanges, OnDestroy, AfterViewInit, AfterContentChecked {
    elRef: ElementRef<HTMLElement>;
    private helper;
    private dataPrepareService;
    private dataVirtualScrollService;
    class: boolean;
    readonly showEmptyView: boolean;
    private queryHeader;
    private queryBody;
    private paginateComp;
    private headerShadowEl;
    private loadingEl;
    /** THAT WILL DEFINE THE DATA TABLE HEIGHT, AND IT WILL HAS SCROLL BAR IN CASE OF OVERFLOW.*/
    height: string;
    /** IF THE ROWS IT WILL HAVE CLICK (JUST ENABLED HOVER EFFECT AND CURSOR AS POINTER) */
    clickable: boolean;
    /** THIS DEFINE IF WILL GO PAGINATE OR NOT */
    paginate: number;
    /** THIS DEFINE IF WILL GO BRING DATA BASED ON SCROLLING WHEN TO ARRIVE ON BOTTOM. (BUT USE THIS ONLY WITH SERVER-SIDE) */
    infinity: number;
    /** SHOW LOADING SPINNER ABOVE THE DATA TABLE WHEN LOADING IS TRUE. */
    loading: boolean;
    /** THE TOTAL DATA LENGTH. THIS IS USED FOR MAKE THE PAGINATION. */
    dataLength: number;
    /** DETERMINES WHETHER DATA WILL BE SWALLOWED VIA SERVER-SIDE */
    serverSide: boolean;
    /** CALL REQUEST DATA ON INITIALIZATION DATA TABLE */
    getDataOnInit: boolean;
    /** SET THE CURRENT PAGE WHEN USE PAGINATION */
    currentPage: number;
    /** Notifies that the data is gone (infinite-scroll only). */
    dataAreOver: boolean;
    /** Sets whether to display empty-view or not. */
    noEmptyView: boolean;
    /** Sets a minimum width in ag-table. When the minimum width is reached, the side table will scroll horizontally. */
    minWidth: string;
    allItems: any[];
    /** CALL/EMIT EVENT TO GET DATA (SERVER-SIDE) */
    onGetData: EventEmitter<AgTableEvent>;
    /** EMIT EVENT WICH ITEMS HAVEN BEEN RENDERED */
    onDataRender: EventEmitter<AgTableDataRenderEvent<any>>;
    /** EMIT EVENT WHEN THE ag-table HAS ALL BEEN RENDERED */
    onTableRender: EventEmitter<void>;
    filterActivated: EventEmitter<boolean>;
    private paddingTop;
    _height: string;
    items: any[];
    filteredItems: any[];
    readonly header: AgTableHeaderComponent;
    readonly body: AgTableBodyComponent;
    readonly topShadow: boolean;
    readonly bottomShadow: boolean;
    readonly isPaging: number;
    readonly isSorting: {
        col: import("../ag-table").ɵc;
        asc: boolean;
    };
    readonly isFiltering: boolean;
    readonly numPages: number;
    readonly el: HTMLElement;
    dictionary: {};
    initialized: boolean;
    isDataEmpty: boolean;
    private dataPaginatedLength;
    paginateCaptionConfig: {
        start: number;
        end: number;
        total: number;
    };
    actionChange: AgTableChangeAction;
    private DOMisVisible;
    private DOMcountVisibleChange;
    private intervalListenerWidth;
    lastBodyWidth: string;
    lastBodyHeight: string;
    constructor(elRef: ElementRef<HTMLElement>, helper: Helper, dataPrepareService: AgTablePrepareService, dataVirtualScrollService: AgTableVirtualScrollService);
    ngOnInit(): void;
    ngAfterViewInit(): void;
    ngAfterContentChecked(): void;
    ngOnChanges(changes: SimpleChanges): void;
    private onCheckBodyDimensions;
    private checkBodyWidthChange;
    private checkBodyHeightChange;
    private definePaddingBottom;
    definePaddingTop(forceDefine?: boolean): void;
    private heightIsValid;
    private minWidthIsValid;
    private startListenerWidth;
    private stopListenerWidth;
    checkMinWidthcanApply(): void;
    setDataLength(length: number, paginatedLength: number): void;
    onPageChange(currentPage: number, emit?: boolean): void;
    onSortChange(): void;
    onFilterChange(): void;
    private prepareItemsPagingAndFilter;
    emitGetData(resetData?: boolean): void;
    private emitDataRender;
    setCurrentPage(page: number, updateConfig?: boolean): void;
    private updatePaginateConfig;
    private notifyChanges;
    resetFilters(getData?: boolean): void;
    refreshRender(): void;
    ngOnDestroy(): void;
}
